import React, { useContext } from "react";
import { BlockTag } from "@ethersproject/abstract-provider";
import StandardSubtitle from "../../components/StandardSubtitle";
import BlockLink from "../../components/BlockLink";
import NavBlock from "../../components/NavBlock";
import { RuntimeContext } from "../../useRuntime";
import { useLatestBlockNumber } from "../../useLatestBlock";
import {blockBxsURL, blockTxsURL} from "../../url";

type BlockTransactionHeaderProps = {
    blockTag: BlockTag;
};

const BlockBehaviorHeader: React.FC<BlockTransactionHeaderProps> = ({
                                                                           blockTag,
                                                                       }) => {
    const { provider } = useContext(RuntimeContext);
    const latestBlockNumber = useLatestBlockNumber(provider);

    return (
        <StandardSubtitle>
            <div className="flex items-baseline space-x-1">
                <span>Behaviors</span>
                <div className="flex space-x-1 text-sm text-gray-500">
                    <span>For Block</span>
                    <BlockLink blockTag={blockTag} />
                    <NavBlock
                        entityNum={blockTag as number}
                        latestEntityNum={latestBlockNumber}
                        urlBuilder={blockBxsURL}
                    />
                </div>
            </div>
        </StandardSubtitle>
    );
};

export default React.memo(BlockBehaviorHeader);
